pub struct AxActionGateArgs {
pub gate_app_active: bool,
pub gate_window_present: bool,
pub gate_ax_present: bool,
pub gate_ax_unique: bool,
pub gate_timeout_ms: u64,
pub gate_poll_ms: u64,
}Fields
gate_app_active: boolRequire app active gate before mutation.
gate_window_present: boolRequire target window present gate before mutation.
gate_ax_present: boolRequire AX selector to resolve to at least one node before mutation.
gate_ax_unique: boolRequire AX selector to resolve to exactly one node before mutation.
gate_timeout_ms: u64Timeout for gate checks in milliseconds.
gate_poll_ms: u64Poll interval for gate checks in milliseconds.