pub struct ObserveScreenshotArgs {
pub window_id: Option<u32>,
pub active_window: bool,
pub app: Option<String>,
pub window_name: Option<String>,
pub path: Option<PathBuf>,
pub image_format: Option<ImageFormat>,
pub ax_selector: AxSelectorArgs,
pub selector_padding: i32,
pub if_changed: bool,
pub if_changed_baseline: Option<PathBuf>,
pub if_changed_threshold: Option<u32>,
}Fields
window_id: Option<u32>Select by window id.
active_window: boolSelect frontmost active window.
app: Option<String>Select by app name.
window_name: Option<String>Narrow app selection by window title substring.
path: Option<PathBuf>Output path.
image_format: Option<ImageFormat>Output image format.
ax_selector: AxSelectorArgsselector_padding: i32Expand selector frame by N pixels in each direction.
if_changed: boolSkip writing a new screenshot when the capture hash stays within threshold.
if_changed_baseline: Option<PathBuf>Optional baseline image path used for hash comparison.
if_changed_threshold: Option<u32>Maximum allowed hash-distance bits before capture is considered changed.