pub struct WindowActivateArgs {
pub window_id: Option<u32>,
pub active_window: bool,
pub app: Option<String>,
pub window_name: Option<String>,
pub bundle_id: Option<String>,
pub wait_ms: Option<u64>,
pub reopen_on_fail: bool,
}Fields
window_id: Option<u32>Select by window id.
active_window: boolSelect frontmost active window.
app: Option<String>Select by app name.
window_name: Option<String>Narrow app selection by window title substring.
bundle_id: Option<String>Select by bundle id.
wait_ms: Option<u64>Wait up to this many milliseconds for active confirmation.
reopen_on_fail: boolIf activation/confirmation fails, quit and relaunch the target app once then retry.